<h1>Semmy</h1>

> Semantic versioning made easy for Python

* [Features](#features)
* [API](#api)
* [Prerequisites](#prerequisites)
* [Install](#install)
* [Contributing](#contributing)

## Features

* Parses semantic version domain objects from valid strings
* Check if two versions are equal
* Check if version is a pre-release
* Bump (pre-)major, (pre-)minor, and (pre-)patch versions
* Check if version is greater (newer) or lesser (older) than other version (upcoming)

## API

To be written.

Check [unit tests](tests/test_semmy.py) for complete examples.

## Prerequisites

* **Python** >=3.8 or later

## Install

```sh
poetry add semmy
```

Alternatively, for older projects.

```sh
pip install semmy
pip freeze > requirements.txt
```

## Contributing

See [**here**](CONTRIBUTING.md) for instructions.
